==> yandex-traffic-widget_0.1-2.tar.gz: yandex-traffic-widget-0.1/yandex-traffic-widget_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>BaseSettingsDialog</name>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
</context>
<context>
    <name>DisplaySettingsDialog</name>
    <message>
        <source>Display settings</source>
        <translation>Параметры отображения</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Светофор</translation>
    </message>
    <message>
        <source>Rank</source>
        <translation>Баллы</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Время</translation>
    </message>
    <message>
        <source>Hint</source>
        <translation>Описание</translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source> points</source>
        <translation type="obsolete">баллов</translation>
    </message>
    <message>
        <source> point</source>
        <translation type="obsolete">балл</translation>
    </message>
    <message>
        <source>No data</source>
        <translation>Нет данных</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Обновить</translation>
    </message>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>%n балл</numerusform>
            <numerusform>%n балла</numerusform>
            <numerusform>%n баллов</numerusform>
        </translation>
    </message>
    <message>
        <source>Yandex.Traffic</source>
        <translation>Яндекс.Пробки</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Moscow</source>
        <translation>Москва</translation>
    </message>
    <message>
        <source>St.Petersburg</source>
        <translation>Санкт-Петербург</translation>
    </message>
    <message>
        <source>Kiev</source>
        <translation>Киев</translation>
    </message>
    <message>
        <source>Ekaterinburg</source>
        <translation>Екатеринбург</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Никогда</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>1 мин</translation>
    </message>
    <message>
        <source>2 min</source>
        <translation>2 мин</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation>5 мин</translation>
    </message>
    <message>
        <source>15 min</source>
        <translation>15 мин</translation>
    </message>
    <message>
        <source>30 min</source>
        <translation>30 мин</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Системный</translation>
    </message>
    <message>
        <source>English</source>
        <translation>Английский</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>Русский</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Отображение</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Обновление</translation>
    </message>
    <message>
        <source>City: </source>
        <translation type="obsolete">Город: </translation>
    </message>
    <message>
        <source>Data: </source>
        <translation type="obsolete">Данные: </translation>
    </message>
    <message>
        <source>lights</source>
        <translation>светофор</translation>
    </message>
    <message>
        <source>rank</source>
        <translation>баллы</translation>
    </message>
    <message>
        <source>time</source>
        <translation>время</translation>
    </message>
    <message>
        <source>hint</source>
        <translation>описание</translation>
    </message>
    <message>
        <source>Interval: </source>
        <translation type="obsolete">Интервал: </translation>
    </message>
    <message>
        <source>Update via: </source>
        <translation type="obsolete">Обновлять через: </translation>
    </message>
    <message>
        <source>WiFi</source>
        <translation>WiFi</translation>
    </message>
    <message>
        <source>GSM</source>
        <translation>GSM</translation>
    </message>
    <message>
        <source>Update when locked</source>
        <translation>Обновлять при неактивности</translation>
    </message>
    <message>
        <source>Not update when locked</source>
        <translation>Не обновлять при неактивности</translation>
    </message>
    <message>
        <source>City:</source>
        <translation>Город:</translation>
    </message>
    <message>
        <source>Display:</source>
        <translation>Показывать:</translation>
    </message>
    <message>
        <source>Interval:</source>
        <translation>Интервал:</translation>
    </message>
    <message>
        <source>Update via:</source>
        <translation>Обновлять через:</translation>
    </message>
    <message>
        <source>Language</source>
        <translation type="obsolete">Язык интерфейса</translation>
    </message>
    <message>
        <source>Interface language</source>
        <translation>Язык интерфейса</translation>
    </message>
</context>
<context>
    <name>UpdateSettingsDialog</name>
    <message>
        <source>Update settings</source>
        <translation>Параметры обновления</translation>
    </message>
    <message>
        <source>Update via WiFi</source>
        <translation>Обновлять через WiFi</translation>
    </message>
    <message>
        <source>Update via GSM</source>
        <translation>Обновлять через GSM</translation>
    </message>
    <message>
        <source>Update when device locked</source>
        <translation>Обновлять когда устройство неактивно</translation>
    </message>
    <message>
        <source>Update interval</source>
        <translation>Интервал обновления</translation>
    </message>
</context>
</TS>

==> yandex-traffic-widget_0.1-3.tar.gz: yandex-traffic-widget-0.1/yandex-traffic-widget_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>BaseSettingsDialog</name>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
</context>
<context>
    <name>DisplaySettingsDialog</name>
    <message>
        <source>Display settings</source>
        <translation>Параметры отображения</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Светофор</translation>
    </message>
    <message>
        <source>Rank</source>
        <translation>Баллы</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Время</translation>
    </message>
    <message>
        <source>Hint</source>
        <translation>Описание</translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source> points</source>
        <translation type="obsolete">баллов</translation>
    </message>
    <message>
        <source> point</source>
        <translation type="obsolete">балл</translation>
    </message>
    <message>
        <source>No data</source>
        <translation>Нет данных</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Обновить</translation>
    </message>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>%n балл</numerusform>
            <numerusform>%n балла</numerusform>
            <numerusform>%n баллов</numerusform>
        </translation>
    </message>
    <message>
        <source>Yandex.Traffic</source>
        <translation>Яндекс.Пробки</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Moscow</source>
        <translation>Москва</translation>
    </message>
    <message>
        <source>St.Petersburg</source>
        <translation>Санкт-Петербург</translation>
    </message>
    <message>
        <source>Kiev</source>
        <translation>Киев</translation>
    </message>
    <message>
        <source>Ekaterinburg</source>
        <translation>Екатеринбург</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Никогда</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation type="obsolete">1 мин</translation>
    </message>
    <message>
        <source>2 min</source>
        <translation type="obsolete">2 мин</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation type="obsolete">5 мин</translation>
    </message>
    <message>
        <source>15 min</source>
        <translation type="obsolete">15 мин</translation>
    </message>
    <message>
        <source>30 min</source>
        <translation type="obsolete">30 мин</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Системный</translation>
    </message>
    <message>
        <source>English</source>
        <translation>Английский</translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>Русский</translation>
    </message>
    <message>
        <source>1 minute</source>
        <translation>1 минута</translation>
    </message>
    <message>
        <source>2 minutes</source>
        <translation>2 минуты</translation>
    </message>
    <message>
        <source>5 minutes</source>
        <translation>5 минут</translation>
    </message>
    <message>
        <source>15 minutes</source>
        <translation>15 минут</translation>
    </message>
    <message>
        <source>30 minutes</source>
        <translation>30 минут</translation>
    </message>
    <message>
        <source>1 hour</source>
        <translation>1 час</translation>
    </message>
    <message>
        <source>2 hours</source>
        <translation>2 часа</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Отображение</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Обновление</translation>
    </message>
    <message>
        <source>City: </source>
        <translation type="obsolete">Город: </translation>
    </message>
    <message>
        <source>Data: </source>
        <translation type="obsolete">Данные: </translation>
    </message>
    <message>
        <source>lights</source>
        <translation>светофор</translation>
    </message>
    <message>
        <source>rank</source>
        <translation>баллы</translation>
    </message>
    <message>
        <source>time</source>
        <translation>время</translation>
    </message>
    <message>
        <source>hint</source>
        <translation>описание</translation>
    </message>
    <message>
        <source>Interval: </source>
        <translation type="obsolete">Интервал: </translation>
    </message>
    <message>
        <source>Update via: </source>
        <translation type="obsolete">Обновлять через: </translation>
    </message>
    <message>
        <source>WiFi</source>
        <translation>WiFi</translation>
    </message>
    <message>
        <source>GSM</source>
        <translation>GSM</translation>
    </message>
    <message>
        <source>Update when locked</source>
        <translation>Обновлять при неактивности</translation>
    </message>
    <message>
        <source>Not update when locked</source>
        <translation>Не обновлять при неактивности</translation>
    </message>
    <message>
        <source>City:</source>
        <translation>Город:</translation>
    </message>
    <message>
        <source>Display:</source>
        <translation>Показывать:</translation>
    </message>
    <message>
        <source>Interval:</source>
        <translation>Интервал:</translation>
    </message>
    <message>
        <source>Update via:</source>
        <translation>Обновлять через:</translation>
    </message>
    <message>
        <source>Language</source>
        <translation type="obsolete">Язык интерфейса</translation>
    </message>
    <message>
        <source>Interface language</source>
        <translation>Язык интерфейса</translation>
    </message>
</context>
<context>
    <name>UpdateSettingsDialog</name>
    <message>
        <source>Update settings</source>
        <translation>Параметры обновления</translation>
    </message>
    <message>
        <source>Update via WiFi</source>
        <translation>Обновлять через WiFi</translation>
    </message>
    <message>
        <source>Update via GSM</source>
        <translation>Обновлять через GSM</translation>
    </message>
    <message>
        <source>Update when device locked</source>
        <translation>Обновлять когда устройство неактивно</translation>
    </message>
    <message>
        <source>Update interval</source>
        <translation>Интервал обновления</translation>
    </message>
</context>
</TS>
